{% if user.is_authenticated %}
<hr />

<!-- Delete Post -->
<div class="modal hide fade" id="deletePost{{ post.id }}">
  <div class="modal-header">
    <button type="button" class="close" data-dismiss="modal">×</button>
    <h3>{{ _('Delete a single post') }}</h3>
  </div>
  <div class="modal-body">
    <p>{{ _('You are about to delete a single post, this procedure is irreversible') }}</p>
    <p>{{ _('Do you want to proceed?') }}</p>
  </div>
  <div class="modal-footer">
    <a href="javascript:$('#modal-from-dom').modal('hide')" class="btn secondary" data-dismiss="modal">{{ _('No') }}</a>
    <a href="{% url app_forum-post-delete mytopic.slug post.id %}" class="btn btn-danger">{{ _('Yes') }}</a>
  </div>
</div>
<!-- Delete Post -->

<div style="float: right;">
  <div class="btn-group">
    <a class="btn dropdown-toggle btn-inverse" data-toggle="dropdown" href="#">
      {{ _('Actions') }}
      <span class="caret"></span>
    </a>
    <ul class="dropdown-menu">
      {% if post.user == user or es_moderador %}
          <li><a href="{% url app_forum-post-edit mytopic.slug post.id %}"><i class="icon-pencil"></i> {{ _('Edit') }}</a></li>
          {% if es_moderador %}
          <li><a href="{% url app_forum-post-delete mytopic.slug post.id %}" data-toggle="modal" data-target="#deletePost{{ post.id }}"><i class="icon-minus"></i> {{ _('Delete Post') }}</a></li>
          <!-- <li><a href=""><i class="icon-minus-sign"></i> {{ _('Ban user') }}</a></li> -->
          {% endif %}
      {% endif %}
      <li><a href="{% url app_forum-post-reportinnapropiate mytopic.slug post.id %}"><i class="icon-minus-sign"></i> {{ _('Report inappropiate') }}</a></li>
    </ul>
  </div>

</div>
{% endif %}