{% load widgets %}

<div class="forum-bottom">
  <table class="table table-bordered">
    <thead>
      <tr>
        <th>{{ _('Who is online') }}</th>
        <th>{{ _('Last users registered') }}</th>
        <th>{{ _('Last users logged in') }}</th>
        <th>{{ _('Forum Stats') }}</th>
      </tr>
    </thead>
    <tbody>
      <tr>
        <td>{% online_users 5 %}</td>
        <td>{% last_registers 2 %}</td>
        <td>{% last_logins 5 %}</td>
        <td>{% stats %}</td>
      </tr>
    </tbody>
  </table>
</div>
