<section id="articulos">
    <h1 style="margin-left: 0;">{{ _('Last news in the forum') }}</h1>
    {% for topic in topics %}
    <article class="portada">
        <header>
            <time datetime="{{ topic.date_created|date:"d.m.Y" }}" pubdate="pubdate">{{ topic.date_created|date:"d.m.y" }}</time> &#8212;
            <a href="{% url app_forum-topic-list topic.forum.slug topic.slug %}"><h2>{{ topic.title }}</h2></a>
            <p>{{ topic.posts.all.0.body|safe|striptags|truncatewords:25 }}</p>
        </header>
    </article>
    <hr />
    {% endfor %}
</section>

