{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block metas %}
<title>{{ _('Change Password') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}


{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Change Password') }}</li>
  </ul>
  
  <form method="POST" action="" class="password_change form-vertical">
    {% csrf_token %}
    {{ password_change_form.as_p }}
    <button type="submit" name="action" class="btn btn-info">{% trans "Change Password" %}</button>
  </form>
</section>
{% endblock %}
