{% extends "site_base.html" %}
{% load thumbnail %}

{% block metas %}
    <title>{{ settings.SITE_TITLE }} - {{ settings.SITE_TITLE }}</title>
    <meta name="description" content="{{ settings.SITE_DESCRIPTION }}" />
{% endblock %}

{% block breadcrumbs %}
{% endblock %}
