{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block metas %}
<title>{{ _('Password Reset') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}


{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Password Reset') }}</li>
  </ul>
    
    {% if user.is_authenticated %}
    {% include "account/snippets/already_logged_in.html" %}
    {% endif %}
    
    <div class="alert alert-info">{% blocktrans %}We have sent you an e-mail. If you do not receive it within a few minutes, contact us at <a href="mailto:{{ settings.SITE_CONTACT_EMAIL }}">{{ settings.SITE_CONTACT_EMAIL }}</a>.{% endblocktrans %}</div>

</section>
{% endblock %}
