{% extends "site_base.html" %}

{% load i18n %}
{% load account_tags %}

{% block metas %}
<title>{{ _('Set Password') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<section id="forum">
  {% include "rforum/elements/forum-top.html" %}

  <ul class="breadcrumb">
	<li><i class="icon-user"></i> {{ _('Set Password') }}</li>
  </ul>
    
    <form method="POST" action="" class="password_set form-horizontal">
        {% csrf_token %}
        {{ password_set_form.as_p }}
        <input type="submit" name="action" value="{% trans "Set Password" %}" class="btn btn-info"/>
    </form>

</section>
{% endblock %}
