{% extends "site_base.html" %}

{% load url from future %}
{% load i18n %}

{% block metas %}
    <title>{{ _('Verify Your E-mail Address') }} - {{ settings.SITE_TITLE }}</title>
{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
<h1>{% trans "Verify Your E-mail Address" %}</h1>

{% url 'account_email' as email_url %}

<p>{% blocktrans %}This part of the site requires us to verify that
you are who you claim to be. For this purpose, we require that you
verify ownership of your e-mail address. {% endblocktrans %}</p>

<p>{% blocktrans %}We have sent an e-mail to you for
verification. Please click on the link inside this
e-mail. If you do not receive it within a few minutes, contact us
at <a href="mailto:{{ settings.SITE_CONTACT_EMAIL }}">{{ settings.SITE_CONTACT_EMAIL }}</a>. 
{% endblocktrans %}</p>

<p>{% blocktrans %}<strong>Note:</strong> you can still <a href="{{email_url}}">change your e-mail address</a>.{% endblocktrans %}</p>


{% endblock %}
